@@ -7,6 +7,8 @@ from squad_client.core.api import SquadApi
 from squad_client.core.models import Squad
 from squad_client.utils import first
 
+import squad_client.commands.submit_tuxbuild
+
 
 class SubmitTuxbuildCommandTest(unittest.TestCase):
 
@@ -60,11 +62,21 @@ class SubmitTuxbuildCommandTest(unittest.TestCase):
             self.squad.group("my_group").project("my_project").build("next-20201021")
         )
         self.assertIsNotNone(build)
+        self.assertEqual(
+            sorted(squad_client.commands.submit_tuxbuild.ALLOWED_METADATA + ["id"]),
+            sorted(list(build.metadata.__dict__.keys())),
+        )
+        self.assertIsNone(build.metadata.git_branch)
 
         build = (
             self.squad.group("my_group").project("my_project").build("v4.4.4")
         )
         self.assertIsNotNone(build)
+        self.assertEqual(
+            sorted(squad_client.commands.submit_tuxbuild.ALLOWED_METADATA + ["id"]),
+            sorted(list(build.metadata.__dict__.keys())),
+        )
+        self.assertIsNone(build.metadata.git_branch)
 
         for arch in ["arm64", "x86"]:
             environment = (
@@ -84,6 +96,7 @@ class SubmitTuxbuildCommandTest(unittest.TestCase):
         self.assertEqual("fail", test.status)
 
     def test_submit_tuxbuild_buildset(self):
+        os.environ["KERNEL_BRANCH"] = "master"
         proc = self.submit_tuxbuild("tests/data/submit/tuxbuild/buildset.json")
         self.assertTrue(proc.ok, msg=proc.out)
         self.assertIn("Submitting 3 tests", proc.err)
@@ -92,6 +105,11 @@ class SubmitTuxbuildCommandTest(unittest.TestCase):
             self.squad.group("my_group").project("my_project").build("next-20201030")
         )
         self.assertIsNotNone(build)
+        self.assertEqual(
+            sorted(squad_client.commands.submit_tuxbuild.ALLOWED_METADATA + ["id"]),
+            sorted(list(build.metadata.__dict__.keys())),
+        )
+        self.assertEqual(build.metadata.git_branch, os.environ.get("KERNEL_BRANCH"))
 
         environment = (
             self.squad.group("my_group").project("my_project").environment("x86")
